package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````L"4```````!``````````$BQ````
M`````````$``.``-`$``'``;``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````*@9````````J!D`````````
M$`````````$````%`````"``````````(``````````@````````E3X`````
M``"5/@`````````0`````````0````0`````8`````````!@`````````&``
M``````!(2````````$A(`````````!`````````!````!@```."K````````
MX+L```````#@NP```````$@$````````N`0`````````$`````````(````&
M````\*L```````#PNP```````/"[``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M``#`H````````,"@````````P*````````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````X*L```````#@NP```````."[````
M````(`0````````@!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``H``P`0````!````````
M``0````4`````P```$=.50#C^B>`K(==\2FTGR1N]?T-J--IF@0````0````
M`0```$=.50```````P````(``````````````!$````_````!`````@````@
M'!``!4`$AB@"``2`A@"$@HD`(DD@!`B8@!%!N@`""@`````_````0@```$4`
M``!&````3@```$\```!1`````````%0```!5````5@```%@```!:````7```
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP$+ZUX?"Y3\LNN.2?/JA;&"93\.;:PE#UF:OS&;%N9Q`./*+'$)%U>R)
M!W#3,V+;[16,)<P,.I<+I]VC:WZIG)O19<YMX*<""FL:GE`*BA!7H^#[20``
M`````````````````````````````.0````2````````````````````````
M`)8````2`````````````````````````%T!```2````````````````````
M`````&8"```2`````````````````````````#<"```2````````````````
M`````````/H````2``````````````````````````$````@````````````
M`````````````)<!```2`````````````````````````,H"```2````````
M`````````````````/`!```2`````````````````````````+@"```2````
M`````````````````````'0!```2`````````````````````````"L!```2
M`````````````````````````!L!```2`````````````````````````,T!
M```2`````````````````````````.H!```2````````````````````````
M``T!```2`````````````````````````!$"```2````````````````````
M`````'8#```2`````````````````````````!`````@````````````````
M`````````'L!```2`````````````````````````.D````2````````````
M`````````````.,!```2`````````````````````````"P````@````````
M`````````````````$8"```2`````````````````````````(,"```2````
M``````````````````````("```2`````````````````````````$8````2
M`````````````````````````&,````6`````````````````````````$T!
M```2`````````````````````````'8````2````````````````````````
M`-,````2`````````````````````````(<````2````````````````````
M`````,4!```2`````````````````````````+X!```2````````````````
M`````````/4!```2`````````````````````````+<````2````````````
M`````````````!@"```2`````````````````````````-0!```2````````
M`````````````````'P"```2`````````````````````````#\!```2````
M`````````````````````*<"```2`````````````````````````*X!```2
M`````````````````````````.X````2`````````````````````````(8!
M```2`````````````````````````*`"```2````````````````````````
M`-P!```2`````````````````````````$4"```2````````````````````
M`````(L"```2`````````````````````````*(````2````````````````
M`````````&@!```2`````````````````````````)P!```2````````````
M`````````````+4!```2`````````````````````````"D"```2````````
M`````````````````)("```2`````````````````````````"$"```2````
M`````````````````````#0!```2`````````````````````````%0````2
M`````````````````````````$T"```2`````````````````````````)D"
M```2`````````````````````````*0!```2````````````````````````
M`/P!```2`````````````````````````'\#```2``\`X$(```````#6````
M`````-0#```2``\`L#D````````!!P```````%H"```2``\`H",````````,
M`@```````/8"```2``\`\"T````````)`````````!0#```2``\`P$``````
M```@`@```````/H#```2``\``"X````````2`@```````+H#```0`!D`0,``
M``````````````````<#```2``\`(#`````````F`````````"H#```2``\`
M`#8```````!I`````````(L#```1`!$``&`````````$`````````*<#```2
M``\`@%H```````"?`0```````+(#```2``\`X"P````````I`````````,\#
M```0`!D`F,```````````````````.@#```2``\`H#@````````+`0``````
M`!$$```2``\`<#8```````"X`````````)H#```0`!@``,``````````````
M`````$X#```2``\`4#````````!!`0```````,`"```1`!D`0,`````````(
M`````````%\"```1`!D`8,`````````(`````````.$#```0`!@`*,``````
M``````````````<$```1`!@`(,`````````(`````````*`#```2``\`L"4`
M```````B`````````,8#```2``\`,%H```````!)`````````)P#```@`!@`
M`,```````````````````,("```A`!D`0,`````````(`````````&0#```2
M``\`<#@````````A`````````&T"```B`````````````````````````#@#
M```2``\`$"T```````#3`````````%H#```2``\`(%P```````!5`@``````
M`,8````1`!D`<,`````````!`````````!D$```2``\`H#$```````!<!```
M``````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E
M<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A
M<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?<W1A8VM?8VAK
M7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`
M;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R
M;61I<@!R96%D`'-T<G-T<@!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`
M<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`
M;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA
M7V9I;F%L:7IE`'-T<F-H<@!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y
M`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N`%]?
M<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\N-2XS.`!L:6)C+G-O+C8`<&%R
M7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"
M3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D
M:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA7W5P
M9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK
M=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`
M;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N,30`1TQ)
M0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'3$E"0U\R+C,N,@!'3$E"
M0U\R+C,N-`!'3$E"0U\R+C(N-0`````!``$``0`"``,``0`!``(`!``"``(`
M`@`!``$``@`"``$``@`"``$``0`"``(``0`%``(``P`!``$``0`!``$``0`"
M``(``@`!``(``@`"``$``@`"``$`!@`"``(`!0`"``$``0`"``(``P`"``(`
M`0`!``<`"``"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``(``@`!``$``0`!``$``@`!``(``0`!``$``0`````````!``<`[`(``!``
M````````E)&6!@``"``F!```$````+21E@8```<`,00``!`````4:6D-```&
M`#P$```0````LY&6!@``!0!&!```$````'(9:0D```0`400``!````!T&6D)
M```#`%T$```0````=1II"0```@!I!````````."[````````"`````````"0
M)@```````.B[````````"`````````!0)@````````C`````````"```````
M```(P````````"#`````````"`````````#X8@```````+B_````````!@``
M``8``````````````,"_````````!@````<``````````````,B_````````
M!@```!0``````````````-"_````````!@```!@``````````````-B_````
M````!@```%D``````````````."_````````$@```!T``````````````.B_
M````````!@```!X``````````````/"_````````!@```!\`````````````
M`/B_````````!@```#L``````````````$#`````````!0```%``````````
M`````&#`````````!0```%$``````````````'#`````````!0```%P`````
M``````````B^````````!P````$``````````````!"^````````!P````(`
M`````````````!B^````````!P````,``````````````""^````````!P``
M``0``````````````"B^````````!P````4``````````````#"^````````
M!P````@``````````````#B^````````!P````D``````````````$"^````
M````!P````H``````````````$B^````````!P````L``````````````%"^
M````````!P````P``````````````%B^````````!P````T`````````````
M`&"^````````!P````X``````````````&B^````````!P````\`````````
M`````'"^````````!P```!```````````````'B^````````!P```!$`````
M`````````("^````````!P```!(``````````````(B^````````!P```!,`
M`````````````)"^````````!P```!4``````````````)B^````````!P``
M`!8``````````````*"^````````!P```!<``````````````*B^````````
M!P```!D``````````````+"^````````!P```!H``````````````+B^````
M````!P```!L``````````````,"^````````!P```!P``````````````,B^
M````````!P```"```````````````-"^````````!P```"$`````````````
M`-B^````````!P```"(``````````````."^````````!P```",`````````
M`````.B^````````!P```"0``````````````/"^````````!P```"4`````
M`````````/B^````````!P```"8```````````````"_````````!P```"<`
M``````````````B_````````!P```"@``````````````!"_````````!P``
M`"D``````````````!B_````````!P```"H``````````````""_````````
M!P```"L``````````````"B_````````!P```"P``````````````#"_````
M````!P```"T``````````````#B_````````!P```"X``````````````$"_
M````````!P```"\``````````````$B_````````!P```#``````````````
M`%"_````````!P```#$``````````````%B_````````!P```#(`````````
M`````&"_````````!P```#,``````````````&B_````````!P```#0`````
M`````````'"_````````!P```#4``````````````'B_````````!P```#8`
M`````````````("_````````!P```#<``````````````(B_````````!P``
M`#@``````````````)"_````````!P```#D``````````````)B_````````
M!P```#H``````````````*"_````````!P```#P``````````````*B_````
M````!P```#T``````````````+"_````````!P```#X`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%M9\``$B%P'0"_]!(@\0(PP```````````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)4*<``!FD```````````\P\>^E532(/L.(E\)!Q(
MC7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP.AT____
M2(LUU9L``$B+/0:<``!(B?+HCCH``(`]=YP````/A!D!``!(BP7:FP``9$B+
M`("(.@0```.+1"0<C7@$C5@#2&/_2,'G`^BY_O__2(M\)!!$BT0D'$B)P4B)
M!4V<``!(BP=(B0%(C06?/0``2(E!"$B+!<V;``!(B4$02(T%C#T``$B)01A!
M@_@!#XXG`0``2(/'"$&#P`.Z!`````\?@`````!(BP=(8_*#P@%(@\<(2(D$
M\40YPG7J2&/22(L]\)L``$4QP$B-->8'``!(QP31`````(G:Z)?[__^%P`^$
MAP```$B+/<B;``!(C6PD).AN_?__2(GN2(T]QSL``(G#,<#HNP$``$B%P'1O
M2(L]GYL``.@Z^___Z*7\__](BT0D*&1(*P0E*`````^%F````$B#Q#B)V%M=
MP^@C_/__2(D%;)L``$B)QTB%P'1QZ(_\__](BP6HF@``9$B+$,:"+@D```#I
MOO[__TB+/4&;``#H?/O__^EH____2(L]()L``$B%_W0*Z'8=``#I>____TB-
M/>(Z``!(B>[H(@$``$B)!?N:``!(B<=(A<`/A%G____KTKH$````Z?G^__^_
M`0```.C9^O__Z-3\__\/'T``,>U)B=%>2(GB2(/D\%!413'`,<E(C3W5_?__
M_Q4GF@``]&8N#Q^$```````/'T``2(T]09H``$B-!3J:``!(.?AT%4B+!<Z9
M``!(A<!T"?_@#Q^``````,,/'X``````2(T]$9H``$B--0J:``!(*?Y(B?!(
MP>X_2,'X`T@!QDC1_G042(L%E9D``$B%P'0(_^!F#Q]$``###Q^``````/,/
M'OJ`/1::````=2M52(,]<ID```!(B>5T#$B+/9:9``#H&?W__^AD____Q@7N
MF0```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=!5D%505154TB#
M[`A(A?\/A+$```!,BS6"F0``387V#X2A````#[8'28G_28GUA,!T!#P]=5A%
M,>1)BQY(A=MT,TUCY$R)]0\?@`````!,B>),B?Y(B=_HLOG__X7`=0="@#PC
M/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M00^V1"0!28/$`83`=`0\/77N12G\ZY%F#Q]$``!,*?5*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````Q
MP$B)YN@:^___A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(```!(
MB=_H7_O__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@```!U"4B!
MQ*````!;P^B-^O__9F8N#Q^$``````!FD$%505154TB![*@```!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K!"4H````#X4C
M`0``2('$J````%M=05Q!7<-F#Q]$``#H(_G__TB)Q4B%P'3(2(GOZ`/[__](
MA<`/A+(```"`>!,N3(U@$W4008!\)`$`=-T/'X0``````(!X$RX/A*8```!(
MB=_HOOC__TR)YTF)Q>BS^/__08U\!0)(8__H!OC__TV)X4F)V+X!````28G%
M2(G',<!(Q\+_____2(T-*3<``.@P^O__3(GO2(GFZ(7X__],B>^#^/]T$(M$
M)!@E`/```#T`0```=%WHZ/?__TR)[^A`^/__2(GOZ%CZ__](A<`/A57___\/
M'X``````2(GOZ-#Y__](B=_HR/?__^GP_O__#Q\`08!\)`$N#X5.____08!\
M)`(`#X0-____Z3W___\/'P#HF_[__^NAZ!3Y__\/'T``05=!5D%505152(GU
M4TB)^TB#[!AD2(L$)2@```!(B40D"#'`,<"`/CT/E,!(`<5(B>_HN??__TB-
M="0$2(G?28G$,<#HY_S__TB%P`^$!@$``$B)QTF)Q>B3]___3#G@#X/2````
M3&-T)`1)P>8##[8#A,`/A)X!```\/0^$E@$``$B)V`\?``^V4`%(@\`!A-)T
M!8#Z/77O2"G82)A,BRTKE@``2HU\(`+HH?;__TT!]4F)10!(A<!T5DB+!0Z6
M``!(C4L!2HL4,`^V`X@"/#UT(H3`=0WK'`\?@``````\/701#[8!2(/"`4B#
MP0&(`H3`=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)`AD2"L$
M)2@````/A0<!``!(@\086UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(
M5`4`2(/``832=>[KO0\?0`!,BSUQE0``28,_``^$M@```$R)^$4Q[9!(@\`(
M1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+!7>5``"%P'5;QP5IE0```0```$B)
M]^BI]?__2(7`#X1A____36/U3(G^2(G'2<'F`TR)\NCK]O__2(D%!)4``$B)
MP4&-10%$B6PD!$B82,<$P0````#IB/[__V8/'X0``````$R)_^C(]___2(D%
MT90``$B)P4B%P`^$!O___TUC]4G!Y@/KNP\?0``QP.E__O__OA````!%,>WI
M7____^C?]O__9F8N#Q^$```````/'T``055!5%532('L`!```$B##"0`2(/L
M&+K_#P``9$B+!"4H````2(F$)`@0```QP$F)Y$B)^TB)]4B-/1PT``!,B>;H
M&O;__X7`?A*)P8/H`4ACT(`\%`!U2(7`=3Q(BP7-DP``2(GJ2(G>9$B+..CN
M]/__2(N$)`@0``!D2"L$)2@```!U3DB!Q!@0``!;74%<05W##Q]$``")P68/
M'T0``$QCZ;XO````3(GG3(GJZ/WS__](A<!TI$B+!7&3``!,B>E,B>)(B=YD
M2(LXZ'_U___KG^CX]?__#Q^$``````#S#Q[Z4TB+'423``!(C0W-<P``2(TU
M;S,``$B+%3>3``!D2(L[Z(;V__]D2(L[13')6TR-!?LT``!(C17P$P``3(G!
M2(TU6S,``.G1]/__D/,/'OI(BP7UD@``2(L5]I(``$B-#7=S``!(C349,P``
M9$B+..DW]O__#Q^``````/,/'OI54TB![``0``!(@PPD`$B![``0``!(@PPD
M`$B#["AD2(L$)2@```!(B80D&"```#'`2(GC2(VL)!`0``#HR_/__TB-#>XR
M``"Z`1```$B)WT&)P$R-#:<R``"^`0```#'`Z);U__^Z`!```$B)[DB)W^B&
M]/__,<F%P'@NC7@!2(G#2&/_Z"+S__](B<%(A<!T&$ACVTB)[DB)QTB)VNBI
M]?__Q@08`$B)P4B+A"08(```9$@K!"4H````=0U(@<0H(```2(G(6UW#Z)WT
M__]F9BX/'X0``````&:0\P\>^ND7____#Q^``````/,/'OI!5T%6055!5%53
M2('L`!```$B##"0`2('LN````&1(BP0E*````$B)A"2H$```,<!)B?Q(B?-(
MC3T7,@``2(UT)`SH5?C__[XO````3(GG2(G%Z-7S__](A<!T0#'`3(GF2(T]
M]3$``.C_^O__3(G@2(N4)*@0``!D2"L4)2@````/A8(!``!(@<2X$```6UU!
M7$%=05Y!7\,/'P!(B=],C2W$,0``3(TUPS(``.BJ\___3(GN2(G'Z-_S__](
MB<-(A<!TEX`[``^$Y````&8/'T0``$B%[7032(G>2(GOZ*CS__^%P`^$IP``
M`$B)W^AH\O__2(U4`_])B<=(.=-R%^LE9@\?A```````Q@(`2(/J`4@YTW0%
M@#HO=.](B=_H-_+__TF)QTR)Y^@L\O__28U$!P%(/?\/```/AQO___],C;PD
MH````$R)\4F)V#'`2(/L"+H`$```O@$```!,B?]!5$R-#0$Q``#HG//__TB-
M="0@3(G_Z._Q__]:687`=1"+1"0H)0#P```]`(```'1)3(GN,?_H__+__TB)
MPTB%P`^$L_[__X`[``^%(O___TB%[70&@'T`+G070;\!````2(T=B#```.E9
M____#Q]$``"`?0$`=+GKX;X!````3(G_Z#/S__^%P'6F3(G^2(T]9C```.AP
M^?__3(G_Z%CR___I9_[__^AN\O__9F8N#Q^$```````/'P#S#Q[Z4[XO````
M2(G[Z)[Q__](C5`!2(7`2`]%VDB)WUOI&O+__V8N#Q^$``````#S#Q[Z55-(
M@>P`$```2(,,)`!(@^P89$B+!"4H````2(F$)`@0```QP$B%_P^$S@```(`_
M`$B)^P^$P@```.C-\/__2(U0`4B!^@`0```/A^0```!(B>5(B>^#^@AR#HG1
M2(G>P>D#\TBE2(GS,<GVP@1T"8L+B0^Y!````/;"`G0.1`^W!`MF1(D$#TB#
MP0*#X@%T!P^V%`N(%`](C40%_T@YQ7(6ZQD/'X0``````,8``$B#Z`%(.>AT
M!8`X+W3OOB\```!(B>_HLO#__TB%P'0M2#G%<EA(B>_H,/'__TB+E"0($```
M9$@K%"4H````=4E(@<08$```6UW##Q\`2(N$)`@0``!D2"L$)2@```!U*4B!
MQ!@0``!(C3WE+@``6UWIZ/#__P\?A```````Q@``ZZ,/'P`QP.NDZ._P__]F
M9BX/'X0```````\?0`#S#Q[Z05=!5D%505152(TMOBX``%-(@^P89$B+!"4H
M````2(E$)`@QP$B-7"0$9I`QP$B)WDB)[^C#]/__2(7`=#9(8U0D!$B+!5*.
M``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(
MC2U<+@``D#'`2(G>2(GOZ'/T__](A<!T-DAC5"0$2(L%`HX``$B-!-!(BU`(
M2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-+10N``"0,<!(
MB=Y(B>_H(_3__TB%P'0V2&-4)`1(BP6RC0``2(T$T$B+4`A(B1!(A=)TTF:0
M2(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(TMS2T``)`QP$B)WDB)[^C3\___
M2(7`=#9(8U0D!$B+!6*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)
M$$B%TG7PZ[YF#Q]$``!(C2V$+0``D#'`2(G>2(GOZ(/S__](A<!T-DAC5"0$
M2(L%$HT``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/
M'T0``$R-)40M``"0,<!(B=Y,B>?H,_/__TB%P'0V2&-4)`1(BP7"C```2(T$
MT$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TEJ2P`
M`)`QP$B)WDR)Y^CC\O__2(7`=#9(8U0D!$B+!7*,``!(C0302(M0"$B)$$B%
MTG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C36P+```D#'`2(G>3(GW
MZ)/R__](A<!T-DAC5"0$2(L%(HP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(
M@\`(2(D02(72=?#KOF8/'T0``$R-+6HL``"0,<!(B=Y,B>_H0_+__TB%P'0V
M2&-4)`1(BP72BP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U
M\.N^9@\?1```3(T])"P``)`QP$B)WDR)_^CS\?__2(7`=#9(8U0D!$B+!8*+
M``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,
MC3UR*P``D#'`2(G>3(G_Z*/Q__](A<!T-DAC5"0$2(L%,HL``$B-!-!(BU`(
M2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B)WDB-/8LK``#H
M6?'__TB%P'0-2(G&3(GO,<#H%_3__S'`2(G>2(T]>2L``.@V\?__2(7`=!%(
MB<9(C3UW*P``,<#H\//__TB)WDB-/7$K```QP.@/\?__2(G&2(7`=#E,B><Q
MP.C-\___2(M$)`AD2"L$)2@```!U1$B#Q!A(B>](C35;*P``,<!;74%<05U!
M7D%?Z9[S__\QP$B)WDB-/2TK``#HO?#__TB%P'2[2(G&3(GW,<#H>_/__^NL
MZ(3L__\/'T``\P\>^DB#[!A(C3V@*@``9$B+!"4H````2(E$)`@QP$B-="0$
MZ'?P__](A<!T,@^V$(#Z,`^4P(32#Y3""="#\`$/ML!(BU0D"&1(*Q0E*```
M`'402(/$&,,/'X``````,<#KX.@7[/__#Q^``````/,/'OI06$B![-@```!(
MB70D*$B)5"0P2(E,)#A,B40D0$R)3"1(A,!T-P\I1"10#RE,)&`/*50D<`\I
MG"2`````#RFD))`````/*:PDH`````\IM"2P````#RF\),````!D2(L$)2@`
M``!(B40D&#'`2(GZ2(V$).````!(B>%(BSUJB0``2(E$)`B^`0```$B-1"0@
MQP0D"````,=$)`0P````2(E$)!#H<NK__[__````Z%CI__\/'X0``````$%4
M55-,C9PD``#__TB![``0``!(@PPD`$PYW'7O2(/L$+H"````,?9D2(L$)2@`
M``!(B80D"``!`#'`08G\2(GCZ'KK__](C6C_2(GJ2,'Z/TC!ZC!(C405``^W
MP$@IT$@IQ0^(JP````\?@``````QTDB)[D2)Y^A#Z___2(/X_P^$I````+H(
M``$`2(G>1(GGZ-GH__^#^/\/A'T```!(F$B#^`=V6$B-1`/X2#G8<DY(C14G
MB```ZPX/'T0``$B#Z`%(.=AR-TB+"D@Y"'7O2"G82`'H2(N4)`@``0!D2"L4
M)2@```!U3TB!Q!```0!;74%<PV8N#Q^$``````!(@>T```$`2(']``#__P^%
M7/___TC'P/_____KNDB-/=<H```QP.@5_O__2(T]O"@``#'`Z`?^___H$NK_
M_V:0\P\>^DB#[`CH0^K__XG'Z*SH__](A<!T`TB+`$B#Q`C#9F8N#Q^$````
M```/'T``\P\>^D%5051,C26(*```54B)_4R)YU-(@^P89$B+!"4H````2(E$
M)`@QP$B-="0$Z,OM__](A<!T"(`X`$B)PW4N2(M$)`AD2"L$)2@````/A;``
M``!(B>Y(@\083(GG,<!;74%<05WI8_#__P\?`$B)[DB)Q^C5Z/__2(7`="!(
MBT0D"&1(*P0E*````'5V2(/$&%M=05Q!7<,/'T0``$B)[^@8Z/__2(G?28G%
MZ`WH__])C7P%`NACY___2(/L"$F)Z+X!````4TC'PO____](B<=)B<5,C0WP
M)@``2(T-[R<``#'`Z(3I__]86DB+1"0(9$@K!"4H````=0A,B>[I4____^C5
MZ/__#Q]$``#S#Q[Z05=(C161)P``2(T-)2<``$%69D@/;L)(C14T)P``28G^
M055(C3UZ)@``05154TB!['@!``!D2(L$)2@```!(B80D:`$``$B-!54F``!(
MC6PD'$C'1"0P`````$C'A"2(`````````$B)[DC'1"10`````&9(#V[(2(T%
M("<``&8/;,%F2`]NT$B-!1@G```/*40D(&9(#V[!9D@/;MA(C0T&)P``9@]L
MPDB-!0`G```/$40D:&9(#V["9D@/;N`QP&8/;,,/$40D>&9(#V[!9@]LQ`\I
M1"1`Z`_L__](A<!T#(`X`$B)PP^%E@0``.@9Z/__B<?H@N;__TB%P`^$Z0,`
M`$R+($V%Y`^$W0,``$R)Y^B5YO__2(U\``'HZ^7__T4/M@0D28G'2(G#183`
M=#I,C2V!)@``#Q]``$4/ML!,B?],B>F^`0```$C'PO____\QP$F#Q`%)@\<"
MZ/OG__]%#[8$)$6$P'713(UL)&!(C3W%)0``ZQ`/'P!)BWT(28/%"$B%_W0S
M2(GN,<#H6>O__TF)Q$B%P'3A@#@`=-Q(B<?H%.S__X7`=-!,B>?H^.;__TF)
MQTB%P'5`3(UD)"!-BSPD387_=#)!@#\`#X0(`P``3(G_Z.#K__^%P`^%``$`
M`$V+?"0(28/$"$V%_W789BX/'X0``````$R)_^BHY?__2(G?28G$Z)WE__]%
MC:0$!`0``$UCY$R)Y^CJY/__4TV)^$R-#8\D``!)B<5(C060)0``O@$```!(
MQ\+_____4$B-#7,E``!,B>\QP.@'Y___3(GOOL`!``#H:N?__U]!6(/X_W42
MZ"WF__]$BPA!@_D1#X7=`@``2(VT))````!,B>_H<.;__XG#A<!T<DF+#DB+
M/1"$``!-B>@QP$B-%=0E``"^`0```.@*Y/__13'D2(N$)&@!``!D2"L$)2@`
M```/A1X$``!(@<1X`0``3(G@6UU!7$%=05Y!7\,/'P!,B?])@\0(Z+SE__])
MB<=(A<`/A,7^___I^_[__P\?`(N$)*@````E`/```#T`0```#X5W____1(N\
M)*P```#HY.7__T$YQP^%8?___XN$)*@````E_P$``#W``0``#X5*____3(GG
MZ+SC__](B>Y(C3TT)```28G$,<#HB.G__TB%P`^$3P(``$F+/DB)QNC4\/__
M28G'2(7`#X0X`@``3(G_Z"#D__](B<*#^`-^0$B82(TU+R0``$B)5"0(28U\
M!_SH,.7__X7`=21(BU0D"(/Z!`^$\0(``(U"^TB808`\!R\/A.$"``!F#Q]$
M``!(B>Y(C2T=(P``,<!(B>_H!.G__TB%P`^$VP$```^V`(3`#X30`0``/#`/
MA,@!``!(B>](C35:(P``,<#HI^O__TB-+?0C``!,C37;(P``Z$3C__]52,?"
M_____TV)Z%!,C0V!(@``O@$```!,B>=(C0VF(P``,<#H"^7__UA:ZT</'X``
M````Z#OD__^#.!%U2.@!X___@\,!2(/L"$V)Z%5,C0T_(@``3(GQO@$```!3
M2,?"_____TR)YU`QP.C$Y/__2(/$(+[``0``3(GGZ"/E__^#^/]TKDR)[^CF
MXO__3(GF2(T]Y"$``#'`Z/7J__],B>?H'?K__^GA_?__#Q^$``````!%,?_I
M&/W__P\?A```````2(M\)$!(C5PD0$B%_W0BD#'`2(GNZ.;G__](A<!T!8`X
M`'4T2(M["$B#PPA(A?]UW[\-````3(TE:B(``.C>X?__0;A3````28G'2(G#
MZ?+[__\/'T0``$B)Q^A@X___28G$2(7`=+SIMOO__TF+#DB+/4F!``!-B>@Q
MP$B-%<TB``"^`0```.A#X?__Z33]__]F#Q]$``!(B<?H8/G__TB+A"1H`0``
M9$@K!"4H````#X5'`0``2('$>`$``$B)WUM=05Q!74%>05_I\.+__TV+/NG`
M_?__#Q^$```````Q]DR)_S'`Z%3B__]!B<:%P`^$(?[__XG'Z)+W__])B<=(
MA<`/B`[^__\QTDB-</9$B??H../__TB-M"0J`0``N@8```!$B??HT^#__TB#
M^`8/A<P```"!O"0J`0```$-!0P^%T/W__V:!O"0N`0``2$4/A<#]__\QTDF-
M=\Y$B??HZN+__TB-G"0P`0``NB@```!$B?=(B=[H@N#__TB#^"AU?TB-!9DA
M``"^`0```$V)Z$R)Y\:$)%@!````2(T-4"$``$R-#20@``!(Q\+_____4#'`
M4^BTXO__65[I__W__TV+=@A-A?8/A!C]__],B??HZ.#__TB#^`,/A@;]__])
MC7P&_$B--?<@``#H_>'__X7`30]$_NGJ_/__Z-WA__](C3W@(```,<#HO_7_
M_V9F+@\?A```````#Q]``/,/'OI!5$B-/<8?``!54TB#[!!(BQT&?P``9$B+
M!"4H````2(E$)`@QP$R-9"0$3(GF9$B+*P^VA;````"(A;$````QP.B6Y?__
M2(7`=`F`.#$/A&@!```QP.B!\/__9$B+*TB)[[D#````N@$```!(C36,(```
MZ*3?__](B<5(A<!T*$B+0!!D2(L[2(T5<B```$B+,.BUW___2(M%$$B+,/9&
M#D`/A40!``!D2(L[N0,```"Z`0```$B--4D@``#H6M___TB)Q4B%P'0M3(GF
M2(T]R1X``#'`Z`'E__](B<)(A<`/A.4```!(BT409$B+.TB+,.A5W___9$B+
M.[H!````2(TU`2```.APWO__9$B+.TB-%08@``!(B<;H+=___V1(BP-,B>9(
MC3UG'@``QH"Q`````#'`Z*'D__](B05Z?@``2(G#2(7`=$*^P`$``$B)W^AE
MX?__C5`!@_H!=@F#^!$/A9(```!(BT0D"&1(*P0E*`````^%FP```$B#Q!!;
M74%<PP\?@`````!(BSTQ?@``Z%3W__](B04=?@``2(G#2(7`=:-(C3T6(```
M,<#H5^#__P\?@`````"`>`$`#X29_O__Z8G^__^02(L%\7T``$B+,$B+11!(
MBSCH"NG__^D0____#Q]$``!D2(L[Z+??___IKO[__XG!2(L%P7T``$B)VDB-
M/=\?``!(BS`QP.CUW___Z*#?___S#Q[Z55-(B?M(C3V_'0``2(/L&&1(BP0E
M*````$B)1"0(,<!(C70D!.B2X___2(7`=!P/MA"`^C`/E,"$T@^4P@C0=0I(
MA=MT!8`[`'4A2(M$)`AD2"L$)2@```!U<DB#Q!A;7<-F+@\?A```````2(G?
MZ/CL__^^+P```$B)QTB)Q>AHWO__2(U0`4B%P$@/1>I(B>_HY=[__[H$````
M2(TU]!T``$B)Q^@AW?__A<!UG$B+1"0(9$@K!"4H````=0Y(@\082(G?6UWI
M3^3__^C*WO__9BX/'X0``````$%72(G^3(U'.$%6055!5%532('LF`(``&1(
MBP0E*````$B)A"2(`@``,<!(B>),C8PD@````$B)UP\?@`````!!BP!-BQ!(
M@\<028/`"`_(B<!,B=%(B4?P3(G02,'I($C!Z"A)P>HX)0#_``!,"=!)B<I(
MP>$(2<'B&('A``#_`$6)TDP)T$@)R$B)1_A,.<]UK68/;TPD$&8/;UPD($B-
M1"1H2('":`(``&8/;U0D,&8/;RT'7```#Q^``````/,/;P!F#V_B9@]O4-A(
M@\`09@_O2(AF#^_"9@_OP68/;\AF#W/0'V8/<_$!9@_KP68/;\MF#V_<9@_;
MQ0\I0`A(.=!UNTR+#DR+7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(
MP>`%2`G0`P0D2(V,"YEY@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH
M2,'H`DC!XAY)B?I("<),B=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)
MT4R+5"001(TD"$R)R$R)R4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"
MB<%((?I,,<),`=)-B>))P>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-
MA"B9>8):2`GZ38G52#'0B==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@
M00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(
M,?I(`<I,B<%(P>$%3`GI3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)
MTDF)S4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!
MZ`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)
MP>0%30GL3(ML)#A!`=1(B<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'0
M2<'M&XG12"'X3#'`3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%
MB=)/C80HF7F"6D@)^$V)U4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,
MBVPD2$$!T$R)XDG![`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G4
M3"'02#'X2`'(3(G!2,'A!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY
M@EI,"=!)B<U(,<))P>T;08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,
MB<))P>@"2,'B'HG_3XVD+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@
M28G\2<'D!4T)[$R+;"1@00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)
MY4@QPDG![1N)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(
MP>(>18G23XV$*)EY@EI("?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%
M30GH3(ML)'!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M
M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-
MO"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD
M@`````''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@A
MRDPQTDP!XDF)_$G!Y`5-">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-
ME"*9>8):38GL2#'02<'L&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````
M00'"2(GX2,'@'DC![P)%B=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@Q
MRDP!PDV)T$G!X`5-">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````
M3#'`3"'02HV,*9EY@EI-B>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G1
M2<'J`DC!X1Y!B<5,"=%-B<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ
M2`'73(GJ2<'J&TC!X@5,"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,
M">))B<R)R4@#C"2P````23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)
MP(G`20'$3(GH2<'M`DC!X!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL
M.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)
MB<*)P$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!
MZ`)(P>(>18GB3`G"28G(2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'K
MV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)
MTD@#E"30````2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',
M3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(
MB?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQ
MT$@#C"3@````13'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX
M2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,
MB<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P
M````23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H
M`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(
M`XPD^````$P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``
M2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!
MX1Y$B>=,"=%)B<*)P$@#A"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;
M2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"A
MZ]EN3(G038G02<'H&TC!X`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%
MB>!("?A(B=>)TD@#E"08`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A
M!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B
M3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),
M"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)
M^$C!X!Y(P>\"18GH2`.,)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$
M2(V,.:'KV6Y,B<=)P>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)
MP$TQXHG/2`.$)#@!``!%,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'2
M3(G"2<'H`DC!XAY%B=),"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9
M;DR)T$G!Z!M(P>`%3`G`1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A
M^DTAUDD)UDB+E"1``0``2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,
MB=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&
M30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)
MP4&)R$D)SDTAYDPAPDP)\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!
MYP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D
M6`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!
MX1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)
MT$G!X`5)P>X;30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPA
MT4P)\4R+M"1H`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,
MB=%)P>H"2,'A'D6)Y$P)T4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U
M38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)
MUD&)T$TAUDPAX4P)\4R+M"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,
M"?=)B=8!STR)X4G![`)(P>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$`
M`$D!QDT!\DF)_DP!TDF)^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),
M">I("=%)B=9!B=5((?E-(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G!
M[AM)P>`%30GP28G600'(2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)
M\DR+M"20`0``20'&30'T38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"
M2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF
M3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)
MSDTAYDPAPDP)\DR+M"2@`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!
MUTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!
MQDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),
M">E!B<U)"<Y)(?Y,(>I,"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)
MP>`%30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+
MM"2X`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"
M2,'A'D6)Y$P)T4D)SD&)RDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J
M38GE2<'N&TG!Y05-"?5!`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTA
MT$PAX4P)P4R+A"3(`0``20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y
M3(GG2<'L`DB)T4C!YQY,">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!
MT4V)PD@#A"38`0``2`'*3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>
M08G23`GI2`G/28G-08G.3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G5
M2,'@!4G![1M,">B)P$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+
ME"3@`0``2`'"3`'B38GL2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)
MP>H"20''30GB38G$B=%%B<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)
MS$G![AM)P>0%30GT38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!
MQDT!\$V)UDTQ[D0Q\DV)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"
M2,'B'D6)QD@)RD2)T4V)ZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A
M!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,
M`?E,B[PD$`(``$4QZ$V)U4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)
MP>X"2,'A'D6)Q4P)\4R+M"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ
M2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-
M,=1,B[PD(`(``$4QX$V)]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)
MP>T"2,'B'D6)Q$P)ZDR+K"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA
M2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),
M`?E,B[PD,`(``$4QT$V)ZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>
M2<'L`D6)PDD!QTP)X4R+I"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G2
M2<'L&TC!X@5,">*)TD@!UTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,
M`?I,B[PD0`(``$4Q\$V)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"
M2,'B'D6)QDP)TDR+E"0X`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A
M!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,
M`?E,B[PD8`(``$4QZ$V)U4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"
M2,'A'D6)Q4P)\4R+M"1(`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ
M2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))
M`=1(B<J)R4PQTDD!QT0QPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)
MP>T"2,'B'D6)X$P)ZDR+K"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!
M2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),
M`?E,B[PD<`(``$4QXDV)[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!
MT4G!Z`))`<=-">!,BZ0D:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$
M1#'G38G42`'73(G22<'L&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&
M2`'733'NB?I-`?Q%B<!$,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!
MX4V)U$G!Z@))P>0>B<E-">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':
M3`G'1`-N($B)3@@!^$R)5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B480
M2(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^A6R/__9@\?
M1```\P\>^DB#[`B_@````.A^QO__9@]O!49&``!(QT`P``````\1`&8/;P5#
M1@``QT!X``````\10!!F#V\%0$8```\10"!(@\0(PP\?@`````#S#Q[Z05=(
M8\)!5DF)QD%5051)B?Q52(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H
M2(/2`$C!Z!U(`=!(B4<P2&-'>(7`#X7I````08/^/P^.)P$``$&#[D!%B?=!
MP>\&18UO`4G!Y09)`=V0\P]O`TR)YTB#PT`/$44`\P]O2]`/$4T0\P]O4^`/
M$54@\P]O6_`/$5TPZ*'H__],.>MUS$'!YP9%*?Y)8\9(@_@(<EQ)BU4`28U,
M)$!(@^'X28E4)#A)BU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#^`AR&$B#X/@Q
MTDF+=!4`2(DT$4B#P@A(.<)R[D6)="1X2(/$"%M=05Q!74%>05_#D*@$=71(
MA<!TXD$/ME4`08A4)#BH`G3400^W5`7^9HE4!?[KQP\?0`!!OT````!(C7P%
M`$B)WD$IQT4Y]T4/3_Y-8^],B>KHA<?__T&+1"1X1`'X08E$)'B#^$!UDTR)
MYT4I_DP!Z^C%Y___Z<_^__])B=WI(____T&+50!!B50D.$&+5`7\B50%_.E<
M____D/,/'OI!5DR-=CA!54%454B)_5-,BVXH2(GS3(MF,$R)Z$C!Z`.#X#^-
M4`'&1`8X@$ACRH/Z.`^.A`$``+Y`````3`'Q*=9T#S'`B<*#P`'&!!$`.?!R
M\TB)W^A!Y___9@_OP`\10SA)QT8P`````$$/$48000\11B!,B>)!#[;%3(GO
M3(GN2,'J&$C!X`A,B>%(P>\028G03(GJ2,'N&`^VUD`/MO]`#[;V2,'I$$@)
MT$R)X@^VR4C!X`A("?@/MOY!#[;02,'@"$@)\$$/MO1(P>`(2`GP2,'@"$@)
M^$B)WTC!X`A("<A(P>`(2`G02(E#<.BHYO__2(L#2(G?2,'H&(A%`$B+`TC!
MZ!"(10%(BP.(90)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0B$4%2(M#"(AE
M!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$(AE"DB+0Q"(10M(
MBT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&(AE#DB+0QB(10](BT,@2,'H&(A%
M$$B+0R!(P>@0B$412(M#((AE$DB+0R"(11-;74%<05U!7NEXP___#Q^$````
M``"X.````$D!SC'_*="#^`AR1TF-3@B)PDG'!@````!)QT06^`````!(@^'X
M22G.1`'P@^#X@_@(#X)\_O__@^#X,=*)UH/""$B)/#$YPG+SZ67^__\/'T``
MJ`1U)(7`#X15_O__0<8&`*@"#X1)_O__,=)F08E4!O[I//[__P\?`$''!@``
M``!!QT0&_`````#I)/[__V8N#Q^$``````"02(L-@6$``.D$PO__2(/L"$B#
MQ`C#````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`'-H;W)T
M(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8R`"UE
M`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`````
M````_____P````#_____``````$C16<`````B:O-[P````#^W+J8`````'94
M,A``````\.'2PP````````````````$;`SO\````'@```&!___](`0``T(+_
M_W`!``#@@O__2`8``/"$__\8`0``X(7__X@!``"PAO__U`$``$"'___X`0``
ML(C__S0"``#PBO__@`(``-"+___``@``((S__]P"``!0C/__\`(``#"-__\D
M`P``0(W__S@#``!@C___G`,``)"/__^X`P``X)#___0#``!`E?__0`0``+"5
M__]<!```<);__W@$``"PE___N`0``."7___0!```\)C__RP%````H/__W`4`
M`""B__\0!@```*/__W@&``!PN?__R`8``,"Y___@!@``8+O__RP'``#`O?__
M<`<````````4``````````%Z4@`!>!`!&PP'")`!!Q`4````'````-"#__\B
M```````````````4``````````%Z4@`!>!`!&PP'")`!```D````'````!!^
M__]P`P````X01@X82@\+=PB``#\:.RHS)"(`````%````$0```!8@?__"```
M````````````2````%P```!0A/__S`````!"#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`"````"H
M````U(3__X,`````00X0@P)*#K`!`G$*#A!!#@A!"S@```#,````0(7__VP!
M````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.*$$.($$.&$(.$$(."$<+
M`$@````(`0``=(;__S$"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0.
M.(,'1PY0`Q4!"@XX00XP00XH0@X@0@X80@X00@X(10L\````5`$``&B(___8
M`````$(.$(T"0@X8C`-!#B"&!$$.*(,%1PZH($D.P"`"=@H.*$$.($$.&$(.
M$$(."$8+&````)0!```(B?__3P````!%#A"#`FT."````!````"P`0``/(G_
M_RD`````````,````,0!``!8B?__TP````!%#A"&`D$.&(,#1PZ8($P.F$!)
M#L!``J8*#AA$#A!!#@A!"Q````#X`0``!(K__PD`````````8`````P"````
MBO__$@(```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#K@@3`[P
M(0)Q"@XX00XP00XH0@X@0@X80@X00@X(1`L"N0[X(4\.@"):#O@A00[P(0``
M`!@```!P`@``O(O__R8`````10X0@P)<#@@````X````C`(``-"+__]!`0``
M`$4.$(8"00X8@P-'#I@@20ZP(`+D"@X800X000X(1`M:"@X82`X000X(30M(
M````R`(``.2,__]<!````$8.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9(#CB#
M!T0.4`/^`PH..$T.,$$.*$(.($(.&$(.$$(."$4+&````!0#``#XD/__:0``
M``!(#B`"4`H."$@+`!@````P`P``3)'__[@`````10X000X(1P[@`0`\````
M3`,``/"1__\^`0```$(.$(P"00X8A@-!#B"#!$@,"Z"`!%$-!T0.L(`$`M`*
M#B!!#AA!#A!"#@A+"P``%````(P#``#PDO__(0````!(#A!8#@@`6````*0#
M```(D___"P$```!&#A"-`D(.&(P#2`X@A@1'#BB#!40.0`)""@XH1@X@00X8
M0@X00@X(2`MD"@XH00X@00X80@X00@X(1@MA#DA)#E!C#DA!#D````"L````
M``0``+R3__\!!P```$8.$(\"4`X8C@-1#B"-!$D.*(P%00XPA@9!#CB#!T<.
ML`,#[@$.N`-A#L`#7PZX`T(.L`,";@H..$0.,$$.*$(.($(.&$(.$$(."$0+
M`T4!#K@#2P[``UX.N`-!#K`#7PZX`T0.P`-0#L@#2P[0`TL.L`,##@$*#CA$
M#C!!#BA"#B!"#AA"#A!"#@A%"P+D#K@#0P[``T8.N`-!#K`#`#````"P!```
M')K__R`"````1@X0C`)(#AB&`T$.((,$1`XP`W$!"@X@00X800X00@X(2`LT
M````Y`0```B<___6`````$4.$(8"00X8@P-.#C`"3PH.&$$.$$$."$L+`E<*
M#AA$#A!!#@A%"RP````<!0``D'S__PP"````10X0A@)!#AB#`T0.4`-I`0H.
M&$,.$$$."$$+`````$P```!,!0``@)S__VH6````0@X0CP))#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'1P[0!0-"%@H..$$.,$$.*$(.($(.&$(.$$(."$$+
M````%````)P%``"@LO__20````!(#A`"0`X(2````+0%``#8LO__GP$```!&
M#A"/`D4.&(X#10X@C01"#BB,!40.,(8&10XX@P='#D`"X@H..$$.,$$.*$(.
M($(.&$(.$$(."$(+`$``````!@``++3__U4"````1@X0C@)&#AB-`T(.((P$
M00XHA@5$#C"#!@.9`0H.*$$.($(.&$(.$$(."$T+````````$````$0&``!(
MMO__#```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"0)@```````%`F
M`````````0````````#<`@````````$`````````[`(````````,````````
M```@````````#0````````",7@```````!D`````````X+L````````;````
M``````@`````````&@````````#HNP```````!P`````````"`````````#U
M_O]O`````*`#````````!0````````!@#0````````8`````````D`0`````
M```*`````````'4$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````0!0```````!0`````````
M!P`````````7`````````)@4````````!P`````````8$P````````@`````
M````@`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````)@2````````____;P`````!````````
M`/#__V\`````UA$```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#PNP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````/AB
M````````1T-#.B`H1&5B:6%N(#$S+C(N,"TQ."D@,3,N,BXP```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M
M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA
M;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@`````````8`P```````!@#````````'```````````````````
M``$````````````````````3````!P````(`````````.`,````````X`P``
M`````"`````````````````````(````````````````````)@````<````"
M`````````%@#````````6`,````````D````````````````````!```````
M`````````````#D````'`````@````````!\`P```````'P#````````(```
M``````````````````0```````````````````!'````]O__;P(`````````
MH`,```````"@`P```````/``````````!@`````````(````````````````
M````40````L````"`````````)`$````````D`0```````#0"`````````<`
M```!````"``````````8`````````%D````#`````@````````!@#0``````
M`&`-````````=00```````````````````$```````````````````!A````
M____;P(`````````UA$```````#6$0```````+P`````````!@`````````"
M``````````(`````````;@```/[__V\"`````````)@2````````F!(`````
M``"```````````<````!````"````````````````````'T````$`````@``
M```````8$P```````!@3````````@`$````````&``````````@`````````
M&`````````"'````!````$(`````````F!0```````"8%````````!`%````
M````!@```!<````(`````````!@`````````D0````$````&```````````@
M`````````"`````````7````````````````````!```````````````````
M`(P````!````!@`````````@(````````"`@````````<`,`````````````
M`````!``````````$`````````"7`````0````8`````````D",```````"0
M(P````````@````````````````````(``````````@`````````H`````$`
M```&`````````*`C````````H",```````#L.@``````````````````$```
M`````````````````*8````!````!@````````",7@```````(Q>````````
M"0````````````````````0```````````````````"L`````0````(`````
M`````&``````````8````````,!````````````````````0````````````
M````````M`````$````"`````````,"@````````P*````````#\````````
M````````````!````````````````````,(````!`````@````````#`H0``
M`````,"A````````B`8```````````````````@```````````````````#,
M````#@````,`````````X+L```````#@JP````````@`````````````````
M```(``````````@`````````V`````\````#`````````.B[````````Z*L`
M```````(````````````````````"``````````(`````````.0````&````
M`P````````#PNP```````/"K``````````(````````'``````````@`````
M````$`````````";`````0````,`````````\+T```````#PK0```````!`"
M```````````````````(``````````@`````````[0````$````#````````
M``#``````````+`````````H````````````````````"```````````````
M`````/,````(`````P````````!`P````````"BP````````6```````````
M`````````"````````````````````#X`````0```#``````````````````
M```HL````````!\````````````````````!``````````$``````````0``
M``,`````````````````````````1[`````````!`0``````````````````
0`0``````````````````````
